/*
	File:		CALib.stub.cpp

	Contains:	Container Application Library stub file (public for linking)

	Written by:	Steve Foley

	Copyright:	 1995 by Apple Computer, Inc., all rights reserved.

	Change History (most recent first):

		<4>	 5/11/95		RB		Added CAGetEmbeddedFrameRef
		<3>		 4/23/95	RB		Added CAGetFocusOwner
									Added CAFrameRefValid(), CAFrameRefCopy(), CAFrameRefEqual()
		<2+>	4/20/95		SJF		Cleanup unwanted methods and conform to .exp ordering
		<2>		4/19/95		RB		Updated to CALib Layout API changes
		<1>		4/19/95		SJF		Created file

	To Do:
		- Implement
*/


#ifndef __DRAG__
#include <Drag.h>			// For DragTrackingHandler type, etc.
#endif

#ifndef __EDITIONS__
#include <Editions.h>		// For SectionHandle type, etc.
#endif

#ifndef __CODEFRAGMENTS__
#include <CodeFragments.h>
#endif

#ifndef _CALIB_
#include "CALib.h"
#endif

#pragma segment CALib

//=========================================================================
// CALib Public API - just enough code to build a stub library
//=========================================================================

extern "C" pascal OSErr CALibCFMInit (InitBlockPtr );
pascal OSErr CALibCFMInit (InitBlockPtr )
{
	return (OSErr(0L));

}

//=========================================================================
// Error reporting
//=========================================================================

pascal	OSErr		CAError(		void )
{
	return (OSErr(0L));
}

pascal	CAErrorProc	CASetErrorProc( CAErrorProc )
{
	return (CAErrorProc(0L));
}

//=========================================================================
// Session
//=========================================================================

pascal	void	CAInit(			void )
{
}

pascal	void	CAShutdown(		void )
{
}

//=========================================================================
// Document API
//=========================================================================
pascal	CADocumentRef	CACreateDocument(	FSSpecPtr docSpec, 
											Handle		docHandle)
{
	return (CADocumentRef)0L;
}

pascal	void			CASetDocumentKind(	CADocumentRef, CAISOStr )
{
}

pascal	CAISOStr		CAGetDocumentKind(	CADocumentRef)
{
}

//-------------------------------------------------------------------------
// CAOpenDocument() :
//-------------------------------------------------------------------------
pascal	CADocumentRef	CAOpenDocument(			FSSpecPtr,
												Handle,
												CAOffset,
												CASize)
{
	return (CADocumentRef)0L;
}

pascal	Boolean			CAHasDocumentChanged(	CADocumentRef )
{
	return false;
}

pascal	void 			CASaveDocument(			CADocumentRef,
												FSSpecPtr,
												Handle*,
												CAOffset,
												CASize* )
{
}
												
pascal	void 			CACloseDocument(		CADocumentRef )
{
}


pascal void				CAAddKind(				CADocumentRef document, CAISOStr kind){}
pascal void				CARemoveKind(			CADocumentRef document, CAISOStr kind){}
pascal CAISOStr			CACurrentKind(			CADocumentRef document){}
pascal Boolean			CAUseKind(				CADocumentRef document, CAISOStr kind, short index){}
pascal CAISOStr			CAGetNthKind(			CADocumentRef document, short index){}
pascal short			CAGetKindCount(			CADocumentRef document){}


//=========================================================================
// Stream
//=========================================================================

pascal	void	CARead(			CADocumentRef,
								char*,
								CASize* )
{
}

pascal	void	CAWrite(		CADocumentRef,
								char*,
								CASize* )
{
}

/*
pascal	void	CAWritePromise(	CADocumentRef, CAISOStr, char*, CASize*)
{

}*/

pascal	CASize	CAGetSize(		CADocumentRef )
{
	return (CASize)0L;
}

pascal	CASize	CAGetOffset(	CADocumentRef )
{
	return (CASize)0L;
}

pascal	void	CASetOffset(	CADocumentRef, CASize )
{
}

pascal	void	CAInsert(		CADocumentRef,
								char*,
								CASize* )
{
}

pascal	void	CADelete(		CADocumentRef,
								char*,
								CASize* )
{
}

//=========================================================================
// Data Interchange
//=========================================================================

pascal	CACloneKey	CABeginClone(		CADocumentRef,
										CADocumentRef,
										CACloneKind )
{
	return (CACloneKey)0L;
}

pascal	void		CAEndClone(			CADocumentRef, 
										CADocumentRef, 
										CACloneKey )
{
}

pascal	CAFrameRef		CACloneFrameRef(CAFrameRef,	
										// can be NULL if only one frame in source document
										CADocumentRef,
										CADocumentRef,
										Boolean,
										CACloneKey )
{
}


//=========================================================================
// Clipboard
//=========================================================================

pascal	CADocumentRef CAGetClipboardDocument()
{
	return (CADocumentRef)0L;
}


pascal	void			CAExportClipboard(void)
{

}


//=========================================================================
// Drag and Drop
//=========================================================================

pascal	CADocumentRef CAGetDragDropDocument(	ItemReference	theItem )
{
	return (CADocumentRef)0L;
}

pascal	CADropResult			CAStartDrag(	CADocumentRef	document,
												EventRecord*	event,
												RgnHandle		dragRgn)
{
}

pascal	void			CASetDataSendProc(		CADocumentRef	document,
												DragSendDataUPP sendProc,
												void*			refCon)
{
}

pascal	OSErr CAInstallTrackingHandler( 		DragTrackingHandler,
												WindowPtr,
												 void* )
{
	return noErr;
}

pascal	OSErr CAInstallReceiveHandler( 			DragReceiveHandler,
												WindowPtr,
												void* )
{
	return noErr;
}


pascal OSErr 	CARemoveTrackingHandler( 	DragTrackingHandler, WindowPtr)
{
	return noErr;
}

pascal OSErr 	CARemoveReceiveHandler( 	DragReceiveHandler, WindowPtr)
{
	return noErr;
}

//=========================================================================
// Linking
//=========================================================================

pascal	CADocumentRef	CAGetEditionDocument( SectionHandle*, CACloneKind )
{
	return (CADocumentRef)0L;
}

//=========================================================================
//	Window Management
//=========================================================================

pascal	Boolean	CAIsPartWindow(				WindowPtr )
{
	return true;
}

pascal	WindowPtr		CAGetFrontDocWindow(		void )
{
	return (WindowPtr)0L;
}

pascal	WindowPtr		CAGetFrontFloatingWindow(	void )
{
	return (WindowPtr)0L;
}

pascal	void			CASelectWindow(				WindowPtr )
{
}

pascal	void			CARegisterRootWindow(		WindowPtr,
													CADocumentRef)
{
}

pascal	void			CARegisterFloatingWindow(	WindowPtr)
{
}

pascal	void			CAUnregisterWindow(			WindowPtr )
{
}

//=========================================================================
//	Window Management Callbacks (Optional)
//=========================================================================


pascal	OSErr		CAInstallWindowActivateHandler (CAWindowActivateHandler,
													CADocumentRef)
{
	return noErr;
}

pascal	OSErr		CAInstallFloatingWindowHandlers (	CASelectWindowHandler	handler1,
														CAFrontWindowHandler	handler2,
														CAIsFloaterHandler		handler3)
{
	return noErr;
}

//=========================================================================
// Focus Arbitration ***
//=========================================================================

pascal	Boolean		CARequestStandardFocusSet( 		WindowPtr )
{
	return false;
}

pascal	Boolean		CARequestModalFocus( 			WindowPtr )
{
	return false;
}

pascal	void		CARelinquishStandardFocusSet( 	WindowPtr )
{
}

pascal	void		CARelinquishModalFocus( 		WindowPtr )
{
}

pascal	void		CAInstallFocusNotification( 	CAFocusAcquiredProc,
													CAFocusLostProc,
													CADocumentRef)
{
}



//=========================================================================
// Layout
//=========================================================================

													
pascal	void		CAInstallFrameShapeRequestHandler (	CAFrameShapeRequestHandler handler,
														CADocumentRef	document)
{
}
													
pascal	CAFrameRef	CAGetRootFrameRef (	CADocumentRef)
{
}

pascal	void		CARemoveFrameRef(	CADocumentRef, CAFrameRef )
{
}

pascal	RgnHandle	CAGetFrameRgn(		CADocumentRef, CAFrameRef )
{
	return (RgnHandle)0L;
}

pascal	void		CASetFrameRgn(		CADocumentRef, 
										CAFrameRef, 
										RgnHandle)
{
}

pascal	RgnHandle	CAGetUsedRgn(		CADocumentRef, CAFrameRef)
{
	return (RgnHandle)0L;
}

pascal	void	CAGetFrameTransform(CADocumentRef, CAFrameRef, CATransform*)
{
}

pascal	void	CASetFrameTransform(	CADocumentRef, CAFrameRef, CATransform*)
{
}

pascal	Boolean		CAGetFrozen(			CADocumentRef, CAFrameRef )
{
	return false;
}

pascal	void		CASetFrozen(		CADocumentRef,
										CAFrameRef,
										Boolean )
{
}

pascal Boolean		CAActiveBorderContainsPoint(	Point mouse)
{
	return false;
}

pascal	CAVisFrame	CAGetVisFrame(		CADocumentRef, CAFrameRef )
{
	return (CAVisFrame)0L;
}

pascal	CAVisFrame	CAMakeVisFrame(			CADocumentRef,
											CAFrameRef,
											RgnHandle,
											CATransform*,
											GrafPtr)
{
	return (CAVisFrame)0L;
}

pascal	void		CAAdjustVisFrame(	CAVisFrame,
										RgnHandle,
										CATransform* )
{
}

pascal	void		CARemoveVisFrame(	CAVisFrame)
{
}

pascal void	CAGetVisFrameTransform(	CADocumentRef, CAFrameRef, CATransform*)
{
}


pascal	Boolean		CAGetSelected(		CAVisFrame )
{
	return false;
}

pascal	void		CASetSelected(		CAVisFrame, Boolean )
{
}

pascal	CAHighlight	 CAGetHighlight(	CAVisFrame )
{
	return (CAHighlight)0L;
}

pascal	void		CASetHighlight(		CAVisFrame, CAHighlight )
{
}


pascal void		CAMoveTransformBy(		CATransform*, Point )
{
}

pascal void		CAMoveTransformTo(		CATransform*, Point )
{
}


pascal Boolean CAShowPartFrameInfo(CADocumentRef document, CAVisFrame visFrame)
{
}

pascal void		CAViewFrameInWindow (CADocumentRef, CAFrameRef)
{

}

//=========================================================================
// Imaging
//=========================================================================

pascal	GrafPtr		CAGetCanvas(					CAVisFrame, CAGraphicsSystem )
{
	return (GrafPtr)0L;
}

pascal	void		CADrawFrame(					CAVisFrame, 
													RgnHandle )
{
}

pascal	void		CAInstallCanvasNotification( 	CACanvasUpdatedProc, CADocumentRef )
{
}

pascal	void		CADrawActiveBorder(					void )
{
}
//-------------------------------------------------------------------------
// Menu ***
//-------------------------------------------------------------------------

pascal	void		CASetBaseMenuBar(		Handle )
{
}

pascal	void		CAAdjustMenus(			void )
{
}

pascal	void		CARegisterCommand(		CACommandID,
											CAMenuID,
											CAMenuItemID )
{
}

pascal	Boolean		CADispatchMenuEvent(	EventRecord*, long )
{
	return false;
}

//-------------------------------------------------------------------------
// UI Events ***
//-------------------------------------------------------------------------

pascal	Boolean		CADispatchEvent( 			EventRecord*, CAEventInfo* )
{
	return false;
}


pascal	RgnHandle	CAGetMouseRegion(			void )
{
	return (RgnHandle)0L;
}

pascal	long		CAGetSleepTime(				void )
{
	return 0L;
}

pascal	void		CAInstallBorderAdjuster( 	CADocumentRef, CAAdjustBorderProc )
{
}



//-------------------------------------------------------------------------
// Undo ***
//-------------------------------------------------------------------------

pascal	void		CAClearUndo( void )
{
}

